==> ark_22.04.3.orig.tar.xz: ark-22.04.3/plugins/libsinglefileplugin/kerfuffle_libgz.json.cmake <==
{
    "KPlugin": {
        "Description": "Open and extract single files compressed with the gzip algorithm",
        "Description[ar]": "يفتح و يستخرج الملفات المفردة المضغوطة باستخدام خوارزمية gzip",
        "Description[ast]": "Abre y estrái ficheros comprimíos individuales col algoritmu de gzip",
        "Description[az]": "Gzip alqoritmi ilə sıxılmış tək faylları açmaq və çıxartmaq",
        "Description[bg]": "Отваряне и извличане на единични файлове, компресирани с алгоритъм gzip",
        "Description[ca@valencia]": "Obri i extreu fitxers individuals comprimits amb l'algorisme «gzip»",
        "Description[ca]": "Obre i extreu fitxers individuals comprimits amb l'algorisme «gzip»",
        "Description[cs]": "Otevřít a rozbalit jednotlivé soubory komprimované algoritmem gzip",
        "Description[da]": "Åbn og udpak enkelte filer komprimeret med gzip-algoritmen",
        "Description[de]": "Öffnen und Entpacken von einzelnen mit dem GZip-Algorithmus komprimierten Dateien",
        "Description[el]": "Άνοιγμα και εξαγωγή απλών αρχείων συμπιεσμένα με τον αλγόριθμο gzip",
        "Description[en_GB]": "Open and extract single files compressed with the gzip algorithm",
        "Description[es]": "Abrir y extraer archivos individuales comprimidos con el algoritmo gzip",
        "Description[et]": "Gzipi algoritmiga pakitud failide avamine ja lahtipakkimine",
        "Description[eu]": "Ireki eta erauzi gzip algoritmoarekin konprimatutako fitxategi bakunak",
        "Description[fi]": "Avaa ja pura Gzip-algoritmilla pakattuja yksittäistiedostoja",
        "Description[fr]": "Ouvre et extrait des fichiers compressés avec l'algorithme gzip",
        "Description[gl]": "Abrir e extraer ficheiros individuais comprimidos co algoritmo gzip.",
        "Description[hu]": "A gzip algoritmussal tömörített fájlok megnyitása és kibontása",
        "Description[ia]": "Aperir e extraher singule files comprimite con le algorithmo gzip",
        "Description[id]": "Buka dan ekstrak file tunggal yang dikompresi dengan algoritma gzip",
        "Description[it]": "Apri ed estrai singoli file compressi con l'algoritmo gzip",
        "Description[ko]": "gzip 알고리즘으로 압축된 단일 파일 열고 풀기",
        "Description[nl]": "Open en pak uit losse bestanden gecomprimeerd met het gzip-algoritme",
        "Description[nn]": "Opna og pakk ut einskildfiler komprimerte med gzip-algoritmen",
        "Description[pl]": "Otwiera i wypakowuje pojedyncze pliki spakowane algorytmem gzip",
        "Description[pt]": "Abrir e extrair ficheiros individuais comprimidos com o algoritmo Gzip",
        "Description[pt_BR]": "Abrir e extrair arquivos individuais compactados com o algoritmo Gzip",
        "Description[ro]": "Deschide și extrage fișiere singulare comprimate cu algoritmul gzip",
        "Description[ru]": "Открытие и распаковка отдельных файлов, сжатых по алгоритму gzip",
        "Description[sk]": "Otvorenie a extrahovanie jednotlivých súborov komprimovaných algoritmom gzip",
        "Description[sl]": "Odprite in razširite datoteke stisnjene z algoritmom gzip",
        "Description[sr@ijekavian]": "Отварање и распакивање појединачних фајлова компресованих алгоритмом гзип",
        "Description[sr@ijekavianlatin]": "Otvaranje i raspakivanje pojedinačnih fajlova kompresovanih algoritmom gzip",
        "Description[sr@latin]": "Otvaranje i raspakivanje pojedinačnih fajlova kompresovanih algoritmom gzip",
        "Description[sr]": "Отварање и распакивање појединачних фајлова компресованих алгоритмом гзип",
        "Description[sv]": "Öppna och packa upp enstaka filer komprimerade med gzip-algoritmen",
        "Description[tr]": "Gzip algoritması ile sıkıştırılmış tek dosyaları açın ve çıkarın",
        "Description[uk]": "Здатен відкривати і видобувати дані із окремих файлів, стиснених за допомогою алгоритму gzip",
        "Description[x-test]": "xxOpen and extract single files compressed with the gzip algorithmxx",
        "Description[zh_CN]": "打开和解压 gzip 算法压缩的单个文件",
        "Description[zh_TW]": "開啟並解壓縮以 gzip 演算法壓縮的單一檔案",
        "Id": "kerfuffle_libgz",
        "MimeTypes": [
            "@SUPPORTED_MIMETYPES@"
        ],
        "Name": "Gzip plugin",
        "Name[ar]": "ملحق Gzip",
        "Name[ast]": "Plugin pa gzip",
        "Name[az]": "Gzip qoşması",
        "Name[bg]": "Приставка Gzip",
        "Name[ca@valencia]": "Connector de Gzip",
        "Name[ca]": "Connector del Gzip",
        "Name[cs]": "Modul pro gzip",
        "Name[da]": "Gzip-plugin",
        "Name[de]": "Gzip-Modul",
        "Name[el]": "Πρόσθετο Gzip",
        "Name[en_GB]": "Gzip plugin",
        "Name[es]": "Complemento Gzip",
        "Name[et]": "Gzip'i plugin",
        "Name[eu]": "Gzip plugina",
        "Name[fi]": "Gzip-liitännäinen",
        "Name[fr]": "Module externe « gzip »",
        "Name[gl]": "Complemento de gzip",
        "Name[hu]": "Gzip bővítmény",
        "Name[ia]": "Plugin de Gzip",
        "Name[id]": "Plugin Gzip",
        "Name[it]": "Estensione Gzip",
        "Name[ja]": "Gzip プラグイン",
        "Name[ko]": "Gzip 플러그인",
        "Name[nl]": "Gzip-plug-in",
        "Name[nn]": "Gzip-tillegg",
        "Name[pl]": "Wtyczka gzip",
        "Name[pt]": "'Plugin' do Gzip",
        "Name[pt_BR]": "Plugin Gzip",
        "Name[ro]": "Extensie Gzip",
        "Name[ru]": "Модуль Gzip",
        "Name[sk]": "Plugin Gzip",
        "Name[sl]": "Vstavek Gzip",
        "Name[sr@ijekavian]": "Прикључак за гзип",
        "Name[sr@ijekavianlatin]": "Priključak za gzip",
        "Name[sr@latin]": "Priključak za gzip",
        "Name[sr]": "Прикључак за гзип",
        "Name[sv]": "Gzip-insticksprogram",
        "Name[tr]": "Gzip eklentisi",
        "Name[uk]": "Додаток gzip",
        "Name[x-test]": "xxGzip pluginxx",
        "Name[zh_CN]": "Gzip 插件",
        "Name[zh_TW]": "Gzip 外掛程式",
        "Version": "@RELEASE_SERVICE_VERSION@"
    },
    "X-KDE-Priority": 100
}

==> ark-22.08.0.tar.xz: ark-22.08.0/plugins/libsinglefileplugin/kerfuffle_libgz.json.cmake <==
{
    "KPlugin": {
        "Description": "Open and extract single files compressed with the gzip algorithm",
        "Description[ar]": "يفتح و يستخرج الملفات المفردة المضغوطة باستخدام خوارزمية gzip",
        "Description[ast]": "Abre y estrái ficheros comprimíos individuales col algoritmu de gzip",
        "Description[az]": "Gzip alqoritmi ilə sıxılmış tək faylları açmaq və çıxartmaq",
        "Description[bg]": "Отваряне и извличане на единични файлове, компресирани с алгоритъм gzip",
        "Description[ca@valencia]": "Obri i extrau fitxers individuals comprimits amb l'algorisme «gzip»",
        "Description[ca]": "Obre i extreu fitxers individuals comprimits amb l'algorisme «gzip»",
        "Description[cs]": "Otevřít a rozbalit jednotlivé soubory komprimované algoritmem gzip",
        "Description[da]": "Åbn og udpak enkelte filer komprimeret med gzip-algoritmen",
        "Description[de]": "Öffnen und Entpacken von einzelnen mit dem GZip-Algorithmus komprimierten Dateien",
        "Description[el]": "Άνοιγμα και εξαγωγή απλών αρχείων συμπιεσμένα με τον αλγόριθμο gzip",
        "Description[en_GB]": "Open and extract single files compressed with the gzip algorithm",
        "Description[es]": "Abrir y extraer archivos individuales comprimidos con el algoritmo gzip",
        "Description[et]": "Gzipi algoritmiga pakitud failide avamine ja lahtipakkimine",
        "Description[eu]": "Ireki eta erauzi gzip algoritmoarekin konprimatutako fitxategi bakunak",
        "Description[fi]": "Avaa ja pura Gzip-algoritmilla pakattuja yksittäistiedostoja",
        "Description[fr]": "Ouvre et extrait des fichiers compressés avec l'algorithme gzip",
        "Description[gl]": "Abrir e extraer ficheiros individuais comprimidos co algoritmo gzip.",
        "Description[hu]": "A gzip algoritmussal tömörített fájlok megnyitása és kibontása",
        "Description[ia]": "Aperir e extraher singule files comprimite con le algorithmo gzip",
        "Description[id]": "Buka dan ekstrak file tunggal yang dikompresi dengan algoritma gzip",
        "Description[it]": "Apri ed estrai singoli file compressi con l'algoritmo gzip",
        "Description[ko]": "gzip 알고리즘으로 압축된 단일 파일 열고 풀기",
        "Description[nl]": "Open en pak uit losse bestanden gecomprimeerd met het gzip-algoritme",
        "Description[nn]": "Opna og pakk ut einskildfiler komprimerte med gzip-algoritmen",
        "Description[pl]": "Otwiera i wypakowuje pojedyncze pliki spakowane algorytmem gzip",
        "Description[pt]": "Abrir e extrair ficheiros individuais comprimidos com o algoritmo Gzip",
        "Description[pt_BR]": "Abrir e extrair arquivos individuais compactados com o algoritmo Gzip",
        "Description[ro]": "Deschide și extrage fișiere singulare comprimate cu algoritmul gzip",
        "Description[ru]": "Открытие и распаковка отдельных файлов, сжатых по алгоритму gzip",
        "Description[sk]": "Otvorenie a extrahovanie jednotlivých súborov komprimovaných algoritmom gzip",
        "Description[sl]": "Odprite in razširite datoteke stisnjene z algoritmom gzip",
        "Description[sr@ijekavian]": "Отварање и распакивање појединачних фајлова компресованих алгоритмом гзип",
        "Description[sr@ijekavianlatin]": "Otvaranje i raspakivanje pojedinačnih fajlova kompresovanih algoritmom gzip",
        "Description[sr@latin]": "Otvaranje i raspakivanje pojedinačnih fajlova kompresovanih algoritmom gzip",
        "Description[sr]": "Отварање и распакивање појединачних фајлова компресованих алгоритмом гзип",
        "Description[sv]": "Öppna och packa upp enstaka filer komprimerade med gzip-algoritmen",
        "Description[tr]": "Gzip algoritması ile sıkıştırılmış tek dosyaları açın ve çıkarın",
        "Description[uk]": "Здатен відкривати і видобувати дані із окремих файлів, стиснених за допомогою алгоритму gzip",
        "Description[x-test]": "xxOpen and extract single files compressed with the gzip algorithmxx",
        "Description[zh_CN]": "打开和解压 gzip 算法压缩的单个文件",
        "Description[zh_TW]": "開啟並解壓縮以 gzip 演算法壓縮的單一檔案",
        "Id": "kerfuffle_libgz",
        "MimeTypes": [
            "@SUPPORTED_MIMETYPES@"
        ],
        "Name": "Gzip plugin",
        "Name[ar]": "ملحق Gzip",
        "Name[ast]": "Plugin pa gzip",
        "Name[az]": "Gzip qoşması",
        "Name[bg]": "Приставка Gzip",
        "Name[ca@valencia]": "Connector de Gzip",
        "Name[ca]": "Connector del Gzip",
        "Name[cs]": "Modul pro gzip",
        "Name[da]": "Gzip-plugin",
        "Name[de]": "Gzip-Modul",
        "Name[el]": "Πρόσθετο Gzip",
        "Name[en_GB]": "Gzip plugin",
        "Name[es]": "Complemento Gzip",
        "Name[et]": "Gzip'i plugin",
        "Name[eu]": "Gzip plugina",
        "Name[fi]": "Gzip-liitännäinen",
        "Name[fr]": "Module externe « gzip »",
        "Name[gl]": "Complemento de gzip",
        "Name[hu]": "Gzip bővítmény",
        "Name[ia]": "Plugin de Gzip",
        "Name[id]": "Plugin Gzip",
        "Name[it]": "Estensione Gzip",
        "Name[ja]": "Gzip プラグイン",
        "Name[ko]": "Gzip 플러그인",
        "Name[nl]": "Gzip-plug-in",
        "Name[nn]": "Gzip-tillegg",
        "Name[pl]": "Wtyczka gzip",
        "Name[pt]": "'Plugin' do Gzip",
        "Name[pt_BR]": "Plugin Gzip",
        "Name[ro]": "Extensie Gzip",
        "Name[ru]": "Модуль Gzip",
        "Name[sk]": "Plugin Gzip",
        "Name[sl]": "Vstavek Gzip",
        "Name[sr@ijekavian]": "Прикључак за гзип",
        "Name[sr@ijekavianlatin]": "Priključak za gzip",
        "Name[sr@latin]": "Priključak za gzip",
        "Name[sr]": "Прикључак за гзип",
        "Name[sv]": "Gzip-insticksprogram",
        "Name[tr]": "Gzip eklentisi",
        "Name[uk]": "Додаток gzip",
        "Name[x-test]": "xxGzip pluginxx",
        "Name[zh_CN]": "Gzip 插件",
        "Name[zh_TW]": "Gzip 外掛程式",
        "Version": "@RELEASE_SERVICE_VERSION@"
    },
    "X-KDE-Priority": 100
}
